data "aws_region" "current" {
}

data "aws_caller_identity" "current" {
}


data "aws_iam_policy_document" "ecs_assume" {
  statement {
    actions = [
      "sts:AssumeRole",
    ]

    principals {
      type = "Service"

      identifiers = [
        "ecs.amazonaws.com",
        "ecs-tasks.amazonaws.com",
        "logs.amazonaws.com",
      ]
    }
  }
}

resource "aws_iam_role" "signalfx_agent" {
  name               = "${var.envname}-signalfx_agent"
  path               = "/"
  assume_role_policy = data.aws_iam_policy_document.ecs_assume.json
}


resource "aws_iam_instance_profile" "signalfx_agent" {
  name = "${var.envname}-signalfx_agent"
  role = aws_iam_role.signalfx_agent.name
}

data "aws_iam_policy_document" "signalfx_agent" {
  statement {
    actions = [
      "s3:*",
    ]

    resources = [
      "arn:aws:s3:::${var.client}-${var.envname}-signalfx-store",
      "arn:aws:s3:::${var.client}-${var.envname}-signalfx-store/*"
     
    ]
  }
}

resource "aws_iam_policy" "signalfx_agent" {
  name   = "${var.envname}-signalfx_agent"
  path   = "/"
  policy =  data.aws_iam_policy_document.signalfx_agent.json
}



resource "aws_iam_role_policy_attachment" "signalfx_agent" {
  role       =  aws_iam_role.signalfx_agent.name
  policy_arn =  aws_iam_policy.signalfx_agent.arn
}


